@@ -56,6 +56,7 @@ class ContractVerifier:
         self,
         token_address: HexAddress,
         user_deposit_whole_balance_limit: int,
+        user_deposit_withdraw_timeout: int,
         token_network_registry_address: HexAddress,
     ) -> None:
         chain_id = ChainID(self.web3.eth.chain_id)
@@ -74,6 +75,7 @@ class ContractVerifier:
         if self.verify_service_contracts_deployment_data(
             token_address=token_address,
             user_deposit_whole_balance_limit=user_deposit_whole_balance_limit,
+            user_deposit_withdraw_timeout=user_deposit_withdraw_timeout,
             deployed_contracts_info=deployment_data,
             token_network_registry_address=token_network_registry_address,
         ):
@@ -93,12 +95,14 @@ class ContractVerifier:
         deployed_contracts_info: DeployedContracts,
         token_address: HexAddress,
         user_deposit_whole_balance_limit: int,
+        user_deposit_withdraw_timeout: int,
         token_network_registry_address: HexAddress,
     ) -> None:
         self._store_deployment_info(services=True, deployment_info=deployed_contracts_info)
         self.verify_deployed_service_contracts_in_filesystem(
             token_address=token_address,
             user_deposit_whole_balance_limit=user_deposit_whole_balance_limit,
+            user_deposit_withdraw_timeout=user_deposit_withdraw_timeout,
             token_network_registry_address=token_network_registry_address,
         )
 
@@ -135,7 +139,7 @@ class ContractVerifier:
             != secret_registry.address
         ):
             raise RuntimeError("secret_registry_address onchain has an unexpected value.")
-        if len(constructor_arguments) != 4:
+        if len(constructor_arguments) != 3:
             raise RuntimeError(
                 "TokenNetworkRegistry received a wrong number of constructor arguments."
             )
@@ -143,14 +147,7 @@ class ContractVerifier:
             raise RuntimeError(
                 "TokenNetworkRegistry's constructor received a different SecretRegistry address."
             )
-        assert (
-            token_network_registry.functions.settlement_timeout_min().call()
-            == constructor_arguments[1]
-        )
-        assert (
-            token_network_registry.functions.settlement_timeout_max().call()
-            == constructor_arguments[2]
-        )
+        assert token_network_registry.functions.settle_timeout().call() == constructor_arguments[1]
 
         return True
 
@@ -173,7 +170,7 @@ class ContractVerifier:
         contracts = deployment_data["contracts"]
 
         # Check blockchain transaction hash & block information
-        receipt = self.web3.eth.get_transaction_receipt(
+        receipt = self.web3.eth.wait_for_transaction_receipt(
             contracts[contract_name]["transaction_hash"]
         )
         if receipt["blockNumber"] != contracts[contract_name]["block_number"]:
@@ -221,6 +218,7 @@ class ContractVerifier:
         self,
         token_address: HexAddress,
         user_deposit_whole_balance_limit: int,
+        user_deposit_withdraw_timeout: int,
         token_network_registry_address: HexAddress,
         deployed_contracts_info: DeployedContracts,
     ) -> bool:
@@ -257,6 +255,7 @@ class ContractVerifier:
             constructor_arguments=user_deposit_constructor_arguments,
             token_address=token_address,
             user_deposit_whole_balance_limit=user_deposit_whole_balance_limit,
+            user_deposit_withdraw_timeout=user_deposit_withdraw_timeout,
             one_to_n_address=one_to_n.address,
             monitoring_service_address=monitoring_service.address,
         )
@@ -283,11 +282,12 @@ def _verify_user_deposit_deployment(
     constructor_arguments: List,
     token_address: HexAddress,
     user_deposit_whole_balance_limit: int,
+    user_deposit_withdraw_timeout: int,
     one_to_n_address: HexAddress,
     monitoring_service_address: HexAddress,
 ) -> None:
     """Check an onchain deployment of UserDeposit and constructor arguments at deployment time"""
-    if len(constructor_arguments) != 2:
+    if len(constructor_arguments) != 3:
         raise RuntimeError("UserDeposit has a wrong number of constructor arguments.")
     if token_address != constructor_arguments[0]:
         raise RuntimeError("UserDeposit received a wrong token address during construction.")
@@ -297,6 +297,10 @@ def _verify_user_deposit_deployment(
         raise RuntimeError("UserDeposit has a wrong whole_balance_limit onchain")
     if user_deposit_whole_balance_limit != constructor_arguments[1]:
         raise RuntimeError("UserDeposit received a wrong whole_balance_limit during construction.")
+    if user_deposit.functions.withdraw_timeout().call() != user_deposit_withdraw_timeout:
+        raise RuntimeError("UserDeposit has a wrong withdraw_timeout onchain")
+    if user_deposit_withdraw_timeout != constructor_arguments[2]:
+        raise RuntimeError("UserDeposit received a wrong withdraw_timeout during construction.")
     if to_checksum_address(user_deposit.functions.one_to_n_address().call()) != one_to_n_address:
         raise RuntimeError("UserDeposit has a wrong OneToN address onchain.")
     onchain_msc_address = to_checksum_address(user_deposit.functions.msc_address().call())
