@@ -8,7 +8,7 @@ from web3 import Web3
 from web3.contract import Contract
 from web3.types import Nonce
 
-from raiden_contracts.constants import TEST_SETTLE_TIMEOUT_MIN, ChannelState, MessageTypeId
+from raiden_contracts.constants import TEST_SETTLE_TIMEOUT, ChannelState, MessageTypeId
 from raiden_contracts.tests.utils import (
     EMPTY_ADDITIONAL_HASH,
     EMPTY_BALANCE_HASH,
@@ -23,7 +23,6 @@ from raiden_contracts.tests.utils import (
     get_participants_hash,
     get_settlement_amounts,
 )
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 from raiden_contracts.tests.utils.constants import DEPLOYER_ADDRESS, OnchainBalanceProof
 from raiden_contracts.utils.proofs import (
     hash_balance_data,
@@ -34,36 +33,30 @@ from raiden_contracts.utils.proofs import (
 from raiden_contracts.utils.type_aliases import (
     AdditionalHash,
     BalanceHash,
-    BlockExpiration,
     ChannelID,
     Locksroot,
     Signature,
+    Timestamp,
     TokenAmount,
 )
 
 
 @pytest.fixture(scope="session")
 def create_channel(token_network: Contract) -> Callable:
-    def get(A: HexAddress, B: HexAddress, settle_timeout: int = TEST_SETTLE_TIMEOUT_MIN) -> Tuple:
+    def get(A: HexAddress, B: HexAddress) -> Tuple:
         # Make sure there is no channel existent on chain
         assert token_network.functions.getChannelIdentifier(A, B).call() == 0
 
         # Open the channel and retrieve the channel identifier
         txn_hash = call_and_transact(
-            token_network.functions.openChannel(
-                participant1=A, participant2=B, settle_timeout=settle_timeout
-            )
+            token_network.functions.openChannel(participant1=A, participant2=B)
         )
 
         # Get the channel identifier
         channel_identifier = token_network.functions.getChannelIdentifier(A, B).call()
 
         # Test the channel state on chain
-        (
-            channel_settle_timeout,
-            channel_state,
-        ) = token_network.functions.getChannelInfo(channel_identifier, A, B).call()
-        assert channel_settle_timeout == settle_timeout
+        channel_state = token_network.functions.getChannelState(channel_identifier, A, B).call()
         assert channel_state == ChannelState.OPENED
 
         return (channel_identifier, txn_hash)
@@ -137,9 +130,8 @@ def create_channel_and_deposit(create_channel: Callable, channel_deposit: Callab
         participant2: HexAddress,
         deposit1: int = 0,
         deposit2: int = 0,
-        settle_timeout: int = TEST_SETTLE_TIMEOUT_MIN,
     ) -> int:
-        channel_identifier = create_channel(participant1, participant2, settle_timeout)[0]
+        channel_identifier = create_channel(participant1, participant2)[0]
 
         if deposit1 > 0:
             channel_deposit(channel_identifier, participant1, deposit1, participant2)
@@ -156,7 +148,7 @@ def withdraw_channel(token_network: Contract, create_withdraw_signatures: Callab
         channel_identifier: int,
         participant: HexAddress,
         withdraw_amount: int,
-        expiration_block: int,
+        withdrawable_until: int,
         partner: HexAddress,
         delegate: Optional[HexAddress] = None,
     ) -> HexBytes:
@@ -170,14 +162,14 @@ def withdraw_channel(token_network: Contract, create_withdraw_signatures: Callab
             channel_identifier,
             participant,
             withdraw_amount,
-            expiration_block,
+            withdrawable_until,
         )
         txn_hash = call_and_transact(
             token_network.functions.setTotalWithdraw(
                 channel_identifier,
                 participant,
                 withdraw_amount,
-                expiration_block,
+                withdrawable_until,
                 signature_participant,
                 signature_partner,
             ),
@@ -198,7 +190,7 @@ def cooperative_settle_channel(
         partner: HexAddress,
         withdraw_amount_participant: int,
         withdraw_amount_partner: int,
-        expiration_block: int,
+        withdrawable_until: int,
         delegate: Optional[HexAddress] = None,
     ) -> HexBytes:
         delegate = delegate or participant
@@ -211,14 +203,14 @@ def cooperative_settle_channel(
             channel_identifier,
             participant,
             withdraw_amount_participant,
-            expiration_block,
+            withdrawable_until,
         )
         (signature_A2, signature_B2) = create_withdraw_signatures(
             [participant, partner],
             channel_identifier,
             partner,
             withdraw_amount_partner,
-            expiration_block,
+            withdrawable_until,
         )
 
         txn_hash = call_and_transact(
@@ -227,11 +219,11 @@ def cooperative_settle_channel(
                 (
                     participant,
                     withdraw_amount_participant,
-                    expiration_block,
+                    withdrawable_until,
                     signature_A1,
                     signature_B1,
                 ),
-                (partner, withdraw_amount_partner, expiration_block, signature_B2, signature_A2),
+                (partner, withdraw_amount_partner, withdrawable_until, signature_B2, signature_A2),
             ),
             {"from": delegate},
         )
@@ -316,10 +308,11 @@ def close_and_update_channel(
 
 @pytest.fixture()
 def create_settled_channel(
-    web3: Web3,
     token_network: Contract,
     create_channel_and_deposit: Callable,
     close_and_update_channel: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> Callable:
     def get(
         participant1: HexAddress,
@@ -328,7 +321,7 @@ def create_settled_channel(
         participant2: HexAddress,
         locked_amount2: int,
         locksroot2: bytes,
-        settle_timeout: int = TEST_SETTLE_TIMEOUT_MIN,
+        settle_timeout: int = TEST_SETTLE_TIMEOUT,
     ) -> int:
         participant1_values = ChannelValues(
             transferred=5,
@@ -353,7 +346,6 @@ def create_settled_channel(
             participant2,
             participant1_values.deposit,
             participant2_values.deposit,
-            settle_timeout,
         )
 
         close_and_update_channel(
@@ -364,7 +356,7 @@ def create_settled_channel(
             participant2_values,
         )
 
-        mine_blocks(web3, settle_timeout)
+        time_travel(get_block_timestamp() + settle_timeout + 1)
 
         call_settle(
             token_network,
@@ -381,7 +373,9 @@ def create_settled_channel(
 
 
 @pytest.fixture()
-def reveal_secrets(web3: Web3, secret_registry_contract: Contract) -> Callable:
+def reveal_secrets(
+    web3: Web3, secret_registry_contract: Contract, get_block_timestamp: Callable
+) -> Callable:
     def get(tx_from: HexAddress, transfers: List[Tuple]) -> None:
         for (expiration, _, secrethash, secret) in transfers:
             assert web3.eth.block_number < expiration
@@ -390,8 +384,8 @@ def reveal_secrets(web3: Web3, secret_registry_contract: Contract) -> Callable:
                 {"from": tx_from},
             )
             assert (
-                secret_registry_contract.functions.getSecretRevealBlockHeight(secrethash).call()
-                == web3.eth.block_number
+                secret_registry_contract.functions.getSecretRevealBlockTime(secrethash).call()
+                == get_block_timestamp()
             )
 
     return get
@@ -468,11 +462,10 @@ def update_state_tests(token_network: Contract, get_block: Callable) -> Callable
         settle_timeout: int,
         txn_hash1: str,
     ) -> None:
-        (settle_block_number, state) = token_network.functions.getChannelInfo(
-            channel_identifier, A, B
-        ).call()
+        state = token_network.functions.getChannelState(channel_identifier, A, B).call()
+        settle_block_number = token_network.functions.settleable_after(channel_identifier).call()
 
-        assert settle_block_number == settle_timeout + get_block(txn_hash1)
+        assert settle_block_number == settle_timeout + get_block(txn_hash1).timestamp
         assert state == ChannelState.CLOSED
 
         (
@@ -533,9 +526,8 @@ def cooperative_settle_state_tests(token_network: Contract, custom_token: Contra
             pre_balance_contract,
         )
 
-        (settle_block_number, state) = token_network.functions.getChannelInfo(
-            channel_identifier, A, B
-        ).call()
+        state = token_network.functions.getChannelState(channel_identifier, A, B).call()
+        settle_block_number = token_network.functions.settleable_after(channel_identifier).call()
         assert settle_block_number == 0
         assert state == ChannelState.REMOVED
 
@@ -598,9 +590,8 @@ def settle_state_tests(token_network: Contract, custom_token: Contract) -> Calla
         if locked_amount_B > 0:
             assert locksroot_B == values_B.locksroot
 
-        (settle_block_number, state) = token_network.functions.getChannelInfo(
-            channel_identifier, A, B
-        ).call()
+        state = token_network.functions.getChannelState(channel_identifier, A, B).call()
+        settle_block_number = token_network.functions.settleable_after(channel_identifier).call()
         assert settle_block_number == 0
         if locked_amount_A > 0 or locked_amount_B > 0:
             assert state == ChannelState.SETTLED
@@ -651,7 +642,7 @@ def withdraw_state_tests(custom_token: Contract, token_network: Contract) -> Cal
         delegate: Optional[HexAddress] = None,
     ) -> None:
         current_withdrawn_participant = total_withdrawn_participant - pre_withdrawn_participant
-        (_, state) = token_network.functions.getChannelInfo(
+        state = token_network.functions.getChannelState(
             channel_identifier, participant, partner
         ).call()
         assert state == ChannelState.OPENED
@@ -824,7 +815,7 @@ def create_withdraw_signatures(token_network: Contract, get_private_key: Callabl
         channel_identifier: ChannelID,
         participant_who_withdraws: HexAddress,
         amount_to_withdraw: TokenAmount,
-        expiration_block: BlockExpiration,
+        withdrawable_until: Timestamp,
         token_network_address: Optional[HexAddress] = None,
         v: int = 27,
     ) -> List[bytes]:
@@ -841,7 +832,7 @@ def create_withdraw_signatures(token_network: Contract, get_private_key: Callabl
                 channel_identifier,
                 participant_who_withdraws,
                 amount_to_withdraw,
-                expiration_block,
+                withdrawable_until,
                 v,
             )
             signatures.append(signature)
