@@ -2,11 +2,10 @@ from typing import Callable
 
 import pytest
 from eth_tester.exceptions import TransactionFailed
-from web3 import Web3
 from web3.contract import Contract
 from web3.exceptions import ValidationError
 
-from raiden_contracts.constants import EMPTY_ADDRESS, TEST_SETTLE_TIMEOUT_MIN, ChannelEvent
+from raiden_contracts.constants import EMPTY_ADDRESS, TEST_SETTLE_TIMEOUT, ChannelEvent
 from raiden_contracts.tests.fixtures.channel import call_settle
 from raiden_contracts.tests.utils import (
     EMPTY_ADDITIONAL_HASH,
@@ -17,7 +16,6 @@ from raiden_contracts.tests.utils import (
     ChannelValues,
     call_and_transact,
 )
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 from raiden_contracts.utils.events import check_new_deposit
 
 
@@ -100,7 +98,6 @@ def test_deposit_notapproved(
     custom_token: Contract,
     create_channel: Callable,
     get_accounts: Callable,
-    web3: Web3,
 ) -> None:
     """Calling setTotalDeposit() fails without approving transfers on the token contract"""
     (A, B) = get_accounts(2)
@@ -108,7 +105,6 @@ def test_deposit_notapproved(
     deposit_A = 1
 
     call_and_transact(custom_token.functions.mint(deposit_A), {"from": A})
-    mine_blocks(web3, 1)
     balance = custom_token.functions.balanceOf(A).call()
     assert balance >= deposit_A, f"minted {deposit_A} but the balance is still {balance}"
 
@@ -249,18 +245,19 @@ def test_deposit_channel_state(
 
 
 def test_deposit_wrong_state_fail(
-    web3: Web3,
     get_accounts: Callable,
     token_network: Contract,
     create_channel: Callable,
     assign_tokens: Callable,
     create_close_signature_for_no_balance_proof: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """setTotalDeposit() fails on Closed or Settled channels."""
     (A, B) = get_accounts(2)
     vals_A = ChannelValues(deposit=2, transferred=0)
     vals_B = ChannelValues(deposit=2, transferred=0)
-    channel_identifier = create_channel(A, B, TEST_SETTLE_TIMEOUT_MIN)[0]
+    channel_identifier = create_channel(A, B)[0]
     assign_tokens(A, vals_A.deposit)
     assign_tokens(B, vals_B.deposit)
     call_and_transact(
@@ -309,7 +306,8 @@ def test_deposit_wrong_state_fail(
             {"from": B}
         )
 
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
+
     call_settle(token_network, channel_identifier, A, vals_A, B, vals_B)
     with pytest.raises(TransactionFailed, match="TN: channel not open"):
         token_network.functions.setTotalDeposit(channel_identifier, A, vals_A.deposit, B).call(
