@@ -5,7 +5,7 @@ from eth_tester.exceptions import TransactionFailed
 from web3 import Web3
 from web3.contract import Contract
 
-from raiden_contracts.constants import TEST_SETTLE_TIMEOUT_MIN, ParticipantInfoIndex
+from raiden_contracts.constants import TEST_SETTLE_TIMEOUT, ParticipantInfoIndex
 from raiden_contracts.tests.fixtures.channel import call_settle
 from raiden_contracts.tests.fixtures.channel_test_values import (
     channel_settle_invalid_test_values,
@@ -24,7 +24,6 @@ from raiden_contracts.tests.utils import (
     is_balance_proof_old,
     were_balance_proofs_valid,
 )
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 from raiden_contracts.utils.pending_transfers import (
     get_pending_transfers_tree_with_generated_lists,
 )
@@ -41,6 +40,8 @@ def test_settlement_outcome(
     close_and_update_channel: Callable,
     settle_state_tests: Callable,
     reveal_secrets: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> Callable:
     def f(
         participants: Tuple,
@@ -83,7 +84,7 @@ def test_settlement_outcome(
 
         close_and_update_channel(channel_identifier, A, vals_A, B, vals_B)
 
-        mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN)
+        time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
 
         pre_balance_A = custom_token.functions.balanceOf(A).call()
         pre_balance_B = custom_token.functions.balanceOf(B).call()
@@ -347,6 +348,8 @@ def test_channel_settle_invalid_balance_proof_values(
     settle_state_tests: Callable,
     reveal_secrets: Callable,
     channel_test_values: Tuple,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """Check the settlement results with invalid balance proofs"""
     (A, B, C, D) = get_accounts(4)
@@ -391,7 +394,7 @@ def test_channel_settle_invalid_balance_proof_values(
 
     close_and_update_channel(channel_identifier, A, vals_A, B, vals_B)
 
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 1)
 
     pre_balance_A = custom_token.functions.balanceOf(A).call()
     pre_balance_B = custom_token.functions.balanceOf(B).call()
