@@ -8,7 +8,7 @@ from web3.exceptions import ValidationError
 
 from raiden_contracts.constants import (
     EMPTY_ADDRESS,
-    TEST_SETTLE_TIMEOUT_MIN,
+    TEST_SETTLE_TIMEOUT,
     ChannelEvent,
     ChannelState,
 )
@@ -20,7 +20,6 @@ from raiden_contracts.tests.utils import (
     UINT256_MAX,
     call_and_transact,
 )
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 from raiden_contracts.utils.events import check_withdraw
 
 
@@ -45,7 +44,7 @@ def test_withdraw_call(
             channel_identifier=channel_identifier,
             participant=0x0,
             total_withdraw=withdraw_A,
-            expiration_block=UINT256_MAX,
+            withdrawable_until=UINT256_MAX,
             participant_signature=signature_A_for_A,
             partner_signature=signature_B_for_A,
         )
@@ -56,7 +55,7 @@ def test_withdraw_call(
             channel_identifier=channel_identifier,
             participant="",
             total_withdraw=withdraw_A,
-            expiration_block=UINT256_MAX,
+            withdrawable_until=UINT256_MAX,
             participant_signature=signature_A_for_A,
             partner_signature=signature_B_for_A,
         )
@@ -67,7 +66,7 @@ def test_withdraw_call(
             channel_identifier=channel_identifier,
             participant=A,
             total_withdraw=-1,
-            expiration_block=UINT256_MAX,
+            withdrawable_until=UINT256_MAX,
             participant_signature=signature_A_for_A,
             partner_signature=signature_B_for_A,
         )
@@ -78,7 +77,7 @@ def test_withdraw_call(
             channel_identifier=channel_identifier,
             participant=A,
             total_withdraw=UINT256_MAX + 1,
-            expiration_block=UINT256_MAX,
+            withdrawable_until=UINT256_MAX,
             participant_signature=signature_A_for_A,
             partner_signature=signature_B_for_A,
         )
@@ -86,55 +85,55 @@ def test_withdraw_call(
     # Failure with the zero address insted of a participant's address
     with pytest.raises(TransactionFailed, match="TN/withdraw: invalid participant sig"):
         token_network.functions.setTotalWithdraw(
-            channel_identifier=channel_identifier,
-            participant=EMPTY_ADDRESS,
-            total_withdraw=withdraw_A,
-            expiration_block=UINT256_MAX,
-            participant_signature=signature_A_for_A,
-            partner_signature=signature_B_for_A,
+            channel_identifier,
+            EMPTY_ADDRESS,
+            withdraw_A,
+            UINT256_MAX,
+            signature_A_for_A,
+            signature_B_for_A,
         ).call({"from": A})
 
     # Failure with zero as the total withdrawn amount
     with pytest.raises(TransactionFailed, match="TN/withdraw: total withdraw is zero"):
         token_network.functions.setTotalWithdraw(
-            channel_identifier=channel_identifier,
-            participant=A,
-            total_withdraw=0,
-            expiration_block=UINT256_MAX,
-            participant_signature=signature_A_for_A,
-            partner_signature=signature_B_for_A,
+            channel_identifier,
+            A,
+            0,
+            UINT256_MAX,
+            signature_A_for_A,
+            signature_B_for_A,
         ).call({"from": A})
 
     # Failure with the empty signature instead of A's
     with pytest.raises(TransactionFailed):  # TODO: why doesn't this throw an error message?
         token_network.functions.setTotalWithdraw(
-            channel_identifier=channel_identifier,
-            participant=A,
-            total_withdraw=withdraw_A,
-            expiration_block=UINT256_MAX,
-            participant_signature=EMPTY_SIGNATURE,
-            partner_signature=signature_B_for_A,
+            channel_identifier,
+            A,
+            withdraw_A,
+            UINT256_MAX,
+            EMPTY_SIGNATURE,
+            signature_B_for_A,
         ).call({"from": A})
 
     # Failure with the empty signature instead of B's
     with pytest.raises(TransactionFailed):  # TODO: why doesn't this throw an error message?
         token_network.functions.setTotalWithdraw(
-            channel_identifier=channel_identifier,
-            participant=A,
-            total_withdraw=withdraw_A,
-            expiration_block=UINT256_MAX,
-            participant_signature=signature_A_for_A,
-            partner_signature=EMPTY_SIGNATURE,
+            channel_identifier,
+            A,
+            withdraw_A,
+            UINT256_MAX,
+            signature_A_for_A,
+            EMPTY_SIGNATURE,
         ).call({"from": A})
 
     call_and_transact(
         token_network.functions.setTotalWithdraw(
-            channel_identifier=channel_identifier,
-            participant=A,
-            total_withdraw=withdraw_A,
-            expiration_block=UINT256_MAX,
-            participant_signature=signature_A_for_A,
-            partner_signature=signature_B_for_A,
+            channel_identifier,
+            A,
+            withdraw_A,
+            UINT256_MAX,
+            signature_A_for_A,
+            signature_B_for_A,
         ),
         {"from": A},
     )
@@ -145,15 +144,13 @@ def test_withdraw_call_near_expiration(
     create_channel_and_deposit: Callable,
     get_accounts: Callable,
     create_withdraw_signatures: Callable,
-    web3: Web3,
+    get_block_timestamp: Callable,
 ) -> None:
-    """setTotalWithdraw() succeeds when expiration_block is one block in the future"""
+    """setTotalWithdraw() succeeds when withdrawable_until is 2 seconds in the future"""
     (A, B) = get_accounts(2)
     withdraw_A = 3
     channel_identifier = create_channel_and_deposit(A, B, 10, 1)
-    # The block must still be one block in the future when the transaction is
-    # processed, so we have to choose an expiration two block in the future
-    expiration = web3.eth.block_number + 2
+    expiration = get_block_timestamp() + 2
 
     (signature_A_for_A, signature_B_for_A) = create_withdraw_signatures(
         [A, B], channel_identifier, A, withdraw_A, expiration
@@ -161,24 +158,25 @@ def test_withdraw_call_near_expiration(
 
     call_and_transact(
         token_network.functions.setTotalWithdraw(
-            channel_identifier=channel_identifier,
-            participant=A,
-            total_withdraw=withdraw_A,
-            expiration_block=expiration,
-            participant_signature=signature_A_for_A,
-            partner_signature=signature_B_for_A,
+            channel_identifier,
+            A,
+            withdraw_A,
+            expiration,
+            signature_A_for_A,
+            signature_B_for_A,
         ),
         {"from": A},
     )
 
 
 def test_withdraw_wrong_state(
-    web3: Web3,
     token_network: Contract,
     create_channel_and_deposit: Callable,
     get_accounts: Callable,
     withdraw_channel: Callable,
     create_close_signature_for_no_balance_proof: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """setTotalWithdraw() should fail on a closed or settled channel"""
     (A, B) = get_accounts(2)
@@ -186,8 +184,8 @@ def test_withdraw_wrong_state(
 
     assert token_network.functions.getChannelIdentifier(A, B).call() == 0
 
-    channel_identifier = create_channel_and_deposit(A, B, 10, 14, TEST_SETTLE_TIMEOUT_MIN)
-    (_, state) = token_network.functions.getChannelInfo(channel_identifier, A, B).call()
+    channel_identifier = create_channel_and_deposit(A, B, 10, 14)
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
     assert state == ChannelState.OPENED
 
     # Channel is open, withdraw must work
@@ -207,13 +205,14 @@ def test_withdraw_wrong_state(
         ),
         {"from": A},
     )
-    (_, state) = token_network.functions.getChannelInfo(channel_identifier, A, B).call()
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
     assert state == ChannelState.CLOSED
 
     with pytest.raises(TransactionFailed, match="TN: channel not open"):
         withdraw_channel(channel_identifier, A, withdraw_A, UINT256_MAX, B)
 
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 2)
+
     call_and_transact(
         token_network.functions.settleChannel(
             channel_identifier,
@@ -228,7 +227,7 @@ def test_withdraw_wrong_state(
         ),
         {"from": A},
     )
-    (_, state) = token_network.functions.getChannelInfo(channel_identifier, A, B).call()
+    state = token_network.functions.getChannelState(channel_identifier, A, B).call()
     assert state == ChannelState.REMOVED
 
     with pytest.raises(TransactionFailed, match="TN: channel not open"):
@@ -517,13 +516,14 @@ def test_withdraw_channel_state(
 
 
 def test_withdraw_replay_reopened_channel(
-    web3: Web3,
     token_network: Contract,
     create_channel: Callable,
     channel_deposit: Callable,
     get_accounts: Callable,
     create_withdraw_signatures: Callable,
     create_close_signature_for_no_balance_proof: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     (A, B) = get_accounts(2)
     deposit_A = 20
@@ -560,7 +560,9 @@ def test_withdraw_replay_reopened_channel(
         ),
         {"from": B},
     )
-    mine_blocks(web3, TEST_SETTLE_TIMEOUT_MIN + 1)
+
+    time_travel(get_block_timestamp() + TEST_SETTLE_TIMEOUT + 2)
+
     call_and_transact(
         token_network.functions.settleChannel(
             channel_identifier1,
