@@ -9,7 +9,7 @@ from web3.contract import Contract
 from raiden_contracts.constants import OneToNEvent
 from raiden_contracts.tests.utils import call_and_transact
 from raiden_contracts.utils.proofs import sign_one_to_n_iou
-from raiden_contracts.utils.type_aliases import BlockExpiration, ChainID, TokenAmount
+from raiden_contracts.utils.type_aliases import ChainID, TokenAmount
 
 
 def test_claim(
@@ -21,6 +21,7 @@ def test_claim(
     create_account: Callable,
     create_service_account: Callable,
     make_iou: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     ev_handler = event_handler(one_to_n_contract)
     A = create_account()
@@ -29,33 +30,33 @@ def test_claim(
 
     # IOU expired
     with pytest.raises(TransactionFailed, match="IOU expired"):
-        bad_expiration = web3.eth.block_number - 1
+        bad_expiration = get_block_timestamp(web3.eth.block_number - 1)
         one_to_n_contract.functions.claim(
-            **make_iou(sender=A, receiver=B, expiration_block=bad_expiration)
+            *make_iou(sender=A, receiver=B, claimable_until=bad_expiration).values()
         ).call({"from": A})
 
     # Wrong OneToN address
     with pytest.raises(TransactionFailed, match="Signature mismatch"):
         one_to_n_contract.functions.claim(
-            **make_iou(sender=A, receiver=B, one_to_n_address=A)
+            *make_iou(sender=A, receiver=B, one_to_n_address=A).values()
         ).call({"from": A})
 
     # Wrong chain_id
     with pytest.raises(TransactionFailed, match="Signature mismatch"):
-        one_to_n_contract.functions.claim(**make_iou(sender=A, receiver=B, chain_id=77)).call(
-            {"from": A}
-        )
+        one_to_n_contract.functions.claim(
+            *make_iou(sender=A, receiver=B, chain_id=77).values()
+        ).call({"from": A})
 
     # bad signature
     with pytest.raises(TransactionFailed, match="Signature mismatch"):
         iou = make_iou(sender=A, receiver=B, amount=10)
         iou2 = make_iou(sender=A, receiver=B, amount=11)
         iou["signature"] = iou2["signature"]  # use signature for wrong amount
-        one_to_n_contract.functions.claim(**iou).call({"from": A})
+        one_to_n_contract.functions.claim(*iou.values()).call({"from": A})
 
     # happy case
     iou = make_iou(sender=A, receiver=B)
-    tx_hash = call_and_transact(one_to_n_contract.functions.claim(**iou), {"from": A})
+    tx_hash = call_and_transact(one_to_n_contract.functions.claim(*iou.values()), {"from": A})
 
     ev_handler.assert_event(
         tx_hash,
@@ -63,7 +64,7 @@ def test_claim(
         dict(
             sender=A,
             receiver=B,
-            expiration_block=iou["expiration_block"],
+            claimable_until=iou["claimable_until"],
             transferred=iou["amount"],
         ),
     )
@@ -72,7 +73,7 @@ def test_claim(
 
     # can't be claimed twice
     with pytest.raises(TransactionFailed, match="Already settled session"):
-        one_to_n_contract.functions.claim(**iou).call({"from": A})
+        one_to_n_contract.functions.claim(*iou.values()).call({"from": A})
 
 
 def test_bulk_claim_happy_path(
@@ -94,7 +95,7 @@ def test_bulk_claim_happy_path(
                 senders=[x["sender"] for x in ious],
                 receivers=[x["receiver"] for x in ious],
                 amounts=[x["amount"] for x in ious],
-                expiration_blocks=[x["expiration_block"] for x in ious],
+                claimable_until_list=[x["claimable_until"] for x in ious],
                 signatures=b"".join(x["signature"] for x in ious),
             ),
             {"from": A},
@@ -124,7 +125,7 @@ def test_bulk_claim_errors(
     senders = [x["sender"] for x in ious]
     receivers = [x["receiver"] for x in ious]
     amounts = [x["amount"] for x in ious]
-    expiration_blocks = [x["expiration_block"] for x in ious]
+    claimable_until_list = [x["claimable_until"] for x in ious]
     signatures = b"".join(x["signature"] for x in ious)
 
     # One value too many to `amounts`
@@ -137,7 +138,7 @@ def test_bulk_claim_errors(
                 senders=senders,
                 receivers=receivers,
                 amounts=amounts + [1],
-                expiration_blocks=expiration_blocks,
+                claimable_until_list=claimable_until_list,
                 signatures=signatures,
             ),
             {"from": A},
@@ -153,7 +154,7 @@ def test_bulk_claim_errors(
                     senders=senders,
                     receivers=receivers,
                     amounts=amounts,
-                    expiration_blocks=expiration_blocks,
+                    claimable_until_list=claimable_until_list,
                     signatures=sig,
                 ),
                 {"from": A},
@@ -166,7 +167,7 @@ def test_bulk_claim_errors(
                 senders=senders,
                 receivers=receivers,
                 amounts=[amounts[0], amounts[1] + 1],
-                expiration_blocks=expiration_blocks,
+                claimable_until_list=claimable_until_list,
                 signatures=signatures,
             ),
             {"from": A},
@@ -195,13 +196,14 @@ def test_claim_by_unregistered_service(
     get_accounts: Callable,
     get_private_key: Callable,
     web3: Web3,
+    get_block_timestamp: Callable,
 ) -> None:
     """OneToN contract should not work for an unregistered service provider."""
     (A, B) = get_accounts(2)
     deposit_to_udc(A, 30)
 
     amount = TokenAmount(10)
-    expiration = BlockExpiration(web3.eth.block_number + 2)
+    expiration = get_block_timestamp() + 30
     chain_id = web3.eth.chain_id
 
     signature = sign_one_to_n_iou(
@@ -209,7 +211,7 @@ def test_claim_by_unregistered_service(
         sender=A,
         receiver=B,
         amount=amount,
-        expiration_block=expiration,
+        claimable_until=expiration,
         one_to_n_address=one_to_n_contract.address,
         chain_id=ChainID(chain_id),
     )
@@ -218,11 +220,11 @@ def test_claim_by_unregistered_service(
     with pytest.raises(TransactionFailed, match="receiver not registered"):
         call_and_transact(
             one_to_n_contract.functions.claim(
-                sender=A,
-                receiver=B,
-                amount=amount,
-                expiration_block=expiration,
-                signature=signature,
+                A,
+                B,
+                amount,
+                expiration,
+                signature,
             ),
             {"from": A},
         )
@@ -237,6 +239,7 @@ def test_claim_with_insufficient_deposit(
     event_handler: Callable,
     create_account: Callable,
     create_service_account: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     ev_handler = event_handler(one_to_n_contract)
     A = create_account()
@@ -245,13 +248,13 @@ def test_claim_with_insufficient_deposit(
     chain_id = web3.eth.chain_id
 
     amount = TokenAmount(10)
-    expiration = BlockExpiration(web3.eth.block_number + 1)
+    expiration = get_block_timestamp() + 15
     signature = sign_one_to_n_iou(
         get_private_key(A),
         sender=A,
         receiver=B,
         amount=amount,
-        expiration_block=expiration,
+        claimable_until=expiration,
         one_to_n_address=one_to_n_contract.address,
         chain_id=ChainID(chain_id),
     )
@@ -272,13 +275,13 @@ def test_claim_with_insufficient_deposit(
     assert user_deposit_contract.functions.balances(B).call() == 6
 
     # claim can be retried when transferred amount was 0
-    expiration = BlockExpiration(web3.eth.block_number + 10)
+    expiration = get_block_timestamp() + 150
     signature = sign_one_to_n_iou(
         get_private_key(A),
         sender=A,
         receiver=B,
         amount=amount,
-        expiration_block=expiration,
+        claimable_until=expiration,
         one_to_n_address=one_to_n_contract.address,
         chain_id=ChainID(chain_id),
     )
@@ -294,5 +297,5 @@ def test_claim_with_insufficient_deposit(
     ev_handler.assert_event(
         tx_hash,
         OneToNEvent.CLAIMED,
-        dict(sender=A, receiver=B, expiration_block=expiration, transferred=4),
+        dict(sender=A, receiver=B, claimable_until=expiration, transferred=4),
     )
