@@ -12,17 +12,15 @@ from raiden_contracts.constants import (
     CONTRACT_TOKEN_NETWORK,
     CONTRACT_TOKEN_NETWORK_REGISTRY,
     CONTRACT_USER_DEPOSIT,
-    TEST_SETTLE_TIMEOUT_MAX,
-    TEST_SETTLE_TIMEOUT_MIN,
+    TEST_SETTLE_TIMEOUT,
     MessageTypeId,
 )
 from raiden_contracts.contract_manager import gas_measurements
 from raiden_contracts.tests.utils import call_and_transact
-from raiden_contracts.tests.utils.blockchain import mine_blocks
 from raiden_contracts.tests.utils.constants import DEPLOYER_ADDRESS, SERVICE_DEPOSIT, UINT256_MAX
 from raiden_contracts.utils.pending_transfers import get_locked_amount, get_pending_transfers_tree
 from raiden_contracts.utils.proofs import sign_one_to_n_iou, sign_reward_proof
-from raiden_contracts.utils.type_aliases import BlockExpiration, ChainID, TokenAmount
+from raiden_contracts.utils.type_aliases import ChainID, TokenAmount
 
 
 @pytest.mark.parametrize("version", [None])
@@ -76,9 +74,8 @@ def print_gas_token_network_registry(
     txhash = deploy_tester_contract_txhash(
         CONTRACT_TOKEN_NETWORK_REGISTRY,
         _secret_registry_address=secret_registry_contract.address,
-        _settlement_timeout_min=TEST_SETTLE_TIMEOUT_MIN,
-        _settlement_timeout_max=TEST_SETTLE_TIMEOUT_MAX,
         _max_token_networks=10,
+        _settle_timeout=TEST_SETTLE_TIMEOUT,
     )
     print_gas(txhash, CONTRACT_TOKEN_NETWORK_REGISTRY + " DEPLOYMENT")
 
@@ -99,11 +96,10 @@ def print_gas_token_network_deployment(
         CONTRACT_TOKEN_NETWORK,
         _token_address=custom_token.address,
         _secret_registry=secret_registry_contract.address,
-        _settlement_timeout_min=TEST_SETTLE_TIMEOUT_MIN,
-        _settlement_timeout_max=TEST_SETTLE_TIMEOUT_MAX,
         _controller=controller,
         _channel_participant_deposit_limit=channel_participant_deposit_limit,
         _token_network_deposit_limit=token_network_deposit_limit,
+        _settle_timeout=TEST_SETTLE_TIMEOUT,
     )
     print_gas(txhash, CONTRACT_TOKEN_NETWORK + " DEPLOYMENT")
 
@@ -156,15 +152,17 @@ def print_gas_channel_cycle(
     print_gas: Callable,
     create_balance_proof: Callable,
     create_balance_proof_countersignature: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """Abusing pytest to print gas costs of TokenNetwork's operations"""
     (A, B, C, D) = get_accounts(4)
-    settle_timeout = 11
+    settle_timeout = TEST_SETTLE_TIMEOUT
 
-    (channel_identifier, txn_hash) = create_channel(A, B, settle_timeout)
+    (channel_identifier, txn_hash) = create_channel(A, B)
     print_gas(txn_hash, CONTRACT_TOKEN_NETWORK + ".openChannel")
 
-    (_, txn_hash) = create_channel(C, D, settle_timeout)
+    (_, txn_hash) = create_channel(C, D)
     print_gas(txn_hash, CONTRACT_TOKEN_NETWORK + ".openChannel")
 
     txn_hash = channel_deposit(channel_identifier, A, 20, B)
@@ -233,7 +231,8 @@ def print_gas_channel_cycle(
     )
     print_gas(txn_hash, CONTRACT_TOKEN_NETWORK + ".updateNonClosingBalanceProof")
 
-    mine_blocks(web3, settle_timeout)
+    time_travel(get_block_timestamp() + settle_timeout + 1)
+
     txn_hash = call_and_transact(
         token_network.functions.settleChannel(
             channel_identifier,
@@ -283,12 +282,11 @@ def print_gas_channel_open_with_deposit(
 ) -> None:
     """Abusing pytest to print gas costs of TokenNetwork's `openChannelWithDeposit`"""
     (A, B) = get_accounts(2)
-    settle_timeout = 11
     deposit = 20
 
     assign_tokens(A, deposit)
     tx_hash = call_and_transact(
-        token_network.functions.openChannelWithDeposit(A, B, settle_timeout, deposit),
+        token_network.functions.openChannelWithDeposit(A, B, deposit),
         {"from": A},
     )
     print_gas(tx_hash, CONTRACT_TOKEN_NETWORK + ".openChannelWithDeposit")
@@ -304,9 +302,8 @@ def print_gas_coop_settle(
 ) -> None:
     """Abusing pytest to print gas costs of cooperative settle"""
     (A, B) = get_accounts(2)
-    settle_timeout = 11
 
-    (channel_identifier, txn_hash) = create_channel(A, B, settle_timeout)
+    (channel_identifier, txn_hash) = create_channel(A, B)
     channel_deposit(channel_identifier, A, 20, B)
 
     txn_hash = cooperative_settle_channel(channel_identifier, A, B, 10, 10, UINT256_MAX, A)
@@ -315,6 +312,7 @@ def print_gas_coop_settle(
 
 @pytest.fixture
 def print_gas_monitoring_service(
+    user_deposit_contract: Contract,
     token_network: Contract,
     monitoring_service_external: Contract,
     get_accounts: Callable,
@@ -327,7 +325,8 @@ def print_gas_monitoring_service(
     print_gas: Callable,
     get_private_key: Callable,
     create_service_account: Callable,
-    web3: Web3,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """Abusing pytest to print gas cost of MonitoringService functions"""
     # setup: two parties + MS
@@ -379,7 +378,14 @@ def print_gas_monitoring_service(
         ),
         {"from": A},
     )
-    mine_blocks(web3, 6)
+
+    closed_at_timestamp = get_block_timestamp()
+    best_case_timestamp = int(closed_at_timestamp + TEST_SETTLE_TIMEOUT * 30 / 100)
+    range_length = int((80 - 30) * TEST_SETTLE_TIMEOUT / 100)
+    ms_offset = (int(A, 16) + int(B, 16) + int(MS, 16)) % range_length
+    first_timestamp_allowed_to_monitor = best_case_timestamp + ms_offset
+
+    time_travel(first_timestamp_allowed_to_monitor + 1)
 
     # MS calls `MSC::monitor()` using c1's BP and reward proof
     txn_hash = call_and_transact(
@@ -399,7 +405,8 @@ def print_gas_monitoring_service(
     )
     print_gas(txn_hash, CONTRACT_MONITORING_SERVICE + ".monitor")
 
-    mine_blocks(web3, 1)
+    withdraw_timeout = user_deposit_contract.functions.withdraw_timeout().call()
+    time_travel(get_block_timestamp() + withdraw_timeout + 1)
 
     # MS claims the reward
     txn_hash = call_and_transact(
@@ -421,6 +428,7 @@ def print_gas_one_to_n(
     get_private_key: Callable,
     create_service_account: Callable,
     create_account: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """Abusing pytest to print gas cost of OneToN functions"""
     A = create_account()
@@ -430,13 +438,13 @@ def print_gas_one_to_n(
     # happy case
     chain_id = web3.eth.chain_id
     amount = TokenAmount(10)
-    expiration = BlockExpiration(web3.eth.block_number + 2)
+    expiration = get_block_timestamp() + 100000
     signature = sign_one_to_n_iou(
         get_private_key(A),
         sender=A,
         receiver=B,
         amount=amount,
-        expiration_block=expiration,
+        claimable_until=expiration,
         one_to_n_address=one_to_n_contract.address,
         chain_id=ChainID(chain_id),
     )
@@ -467,7 +475,7 @@ def print_gas_one_to_n(
                 concat_iou_data(ious, "sender"),
                 concat_iou_data(ious, "receiver"),
                 concat_iou_data(ious, "amount"),
-                concat_iou_data(ious, "expiration_block"),
+                concat_iou_data(ious, "claimable_until"),
                 concat_iou_signatures(ious),
             ),
             {"from": A},
@@ -480,8 +488,9 @@ def print_gas_user_deposit(
     user_deposit_contract: Contract,
     custom_token: Contract,
     get_accounts: Callable,
-    web3: Web3,
     print_gas: Callable,
+    time_travel: Callable,
+    get_block_timestamp: Callable,
 ) -> None:
     """Abusing pytest to print gas cost of UserDeposit functions
 
@@ -505,8 +514,8 @@ def print_gas_user_deposit(
     print_gas(txn_hash, CONTRACT_USER_DEPOSIT + ".planWithdraw")
 
     # withdraw
-    withdraw_delay = user_deposit_contract.functions.withdraw_delay().call()
-    mine_blocks(web3, withdraw_delay)
+    withdraw_timeout = user_deposit_contract.functions.withdraw_timeout().call()
+    time_travel(get_block_timestamp() + withdraw_timeout + 1)
     txn_hash = call_and_transact(user_deposit_contract.functions.withdraw(10), {"from": A})
     print_gas(txn_hash, CONTRACT_USER_DEPOSIT + ".withdraw")
 
